@@ -3,7 +3,7 @@ import mpltern
 
 ax = plt.subplot(projection='ternary')
 
-from mpltern.ternary.datasets import get_spiral
+from mpltern.datasets import get_spiral
 
 t, l, r = get_spiral()
 ax.plot(t, l, r)
@@ -11,7 +11,7 @@ plt.show()
 
 ax = plt.subplot(projection='ternary')
 
-from mpltern.ternary.datasets import get_shanon_entropies
+from mpltern.datasets import get_shanon_entropies
 
 t, l, r, v = get_shanon_entropies()
 ax.tricontourf(t, l, r, v)
