@@ -12,6 +12,9 @@
 #
 import os
 import shutil
+import sys
+
+sys.path.insert(0, os.path.abspath(".."))
 
 from sphinx.transforms import SphinxTransform
 
@@ -24,6 +27,8 @@ import mpltern
 # Add any Sphinx extension module names here, as strings. They can be
 # extensions coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
 extensions = [
+    'sphinx.ext.autodoc',
+    'numpydoc',  # Needs to be loaded *after* autodoc.
     'sphinx_gallery.gen_gallery',
     'sphinx_copybutton',
 ]
@@ -60,6 +65,11 @@ _check_dependencies()
 # On Linux, prevent plt.show() from emitting a non-GUI backend warning.
 os.environ.pop("DISPLAY", None)
 
+intersphinx_mapping = {
+    'matplotlib': ('https://matplotlib.org/stable/', None),
+}
+
+
 from sphinx_gallery.scrapers import matplotlib_scraper
 
 
@@ -84,6 +94,7 @@ sphinx_gallery_conf = {
     'doc_module': ('mpltern', ),
     'subsection_order': ExplicitOrder(['../examples/introductory',
                                        '../examples/intermediate',
+                                       '../examples/statistics',
                                        '../examples/axis_and_tick',
                                        '../examples/triangle',
                                        '../examples/advanced',
@@ -110,7 +121,7 @@ source_encoding = "utf-8"
 master_doc = 'index'  # default: 'contents'
 
 project = 'mpltern'
-copyright = '2019-2022, Yuji Ikeda'
+copyright = '2019-2023, Yuji Ikeda'
 author = 'Yuji Ikeda'
 
 version = mpltern.__version__
@@ -185,6 +196,10 @@ html_favicon = '_static/favicon.ico'
 
 html_logo = '_static/sphx_glr_logos0_002.svg'
 
+# numpydoc config
+
+numpydoc_show_class_members = False
+
 # Workaround to remove matplotlib warning based on
 # https://github.com/sphinx-gallery/sphinx-gallery/pull/521
 
