@@ -6,7 +6,7 @@ Arbitrary triangle
 You can make a ternary plot on an triangle with arbitrary shape.
 """
 import matplotlib.pyplot as plt
-from mpltern.ternary.datasets import get_spiral
+from mpltern.datasets import get_spiral
 
 
 corners = ((0.0, 0.0), (0.5, 0.5), (-0.5, 1.0))
